@@ -1,5 +1,5 @@
 __author__ = 'Gabriel Oliveira'
-__version__ = '0.1.0'
+__version__ = '0.1.1'
 
 from typing import Optional
 
@@ -30,7 +30,9 @@ def plot_word_cloud(ngram_dict: dict,
     :type save_path: Optional[str]
     """
     wc = WordCloud(background_color=background_color,
-                   max_words=max_words).generate_from_frequencies(ngram_dict)
+                   max_words=max_words,
+                   height=1000,
+                   width=1000).generate_from_frequencies(ngram_dict)
     plt.figure(figsize=(width, height))
     plt.imshow(wc, interpolation='bilinear')
     plt.axis('off')
